==> muitv-0.4.3.tgz: package/src/components/demo/ConsumptionArtworkDemo.js <==
import React, { Component } from "react";

import ConsumptionArtwork from "components/layouts/ConsumptionArtwork";

import LinearProgress from "@material-ui/core/LinearProgress";
import { withStyles } from "@material-ui/core/styles";
import IconButton from "@material-ui/core/IconButton";
import DeleteIcon from "@material-ui/icons/Delete";

const styles = theme => ({
  primaryButton1080: {
    margin: theme.spacing.unit,
    height: "3.0em",
    width: "3.0em"
  },
  primaryIcon1080: {
    width: "2.0em",
    height: "2.0em"
  },
  secondaryButton1080: {
    height: "2.2em",
    width: "2.2em"
  },
  secondaryIcon1080: {
    width: "1.8em",
    height: "1.8em"
  },

  primaryButton720: {
    margin: theme.spacing.unit,
    width: "2.4em",
    height: "2.4em"
  },
  primaryIcon720: {
    width: "1.5em",
    height: "1.5em"
  },
  secondaryButton720: {
    width: "1.6em",
    height: "1.6em"
  },
  secondaryIcon720: {
    width: "1.1em",
    height: "1.1em"
  },

  primaryButton: {
    width: 56,
    height: 56
  },
  primaryIcon: {},
  secondaryButton: {},
  secondaryIcon: {},

  button1: {
    margin: theme.spacing.unit,
    height: "2em",
    width: "2em"
  },
  icon1: {
    width: "1em",
    height: "1em"
  },
  button2: {
    margin: theme.spacing.unit * 1.3,
    height: "4.6em",
    width: "4.6em"
  },
  icon2: {
    width: "1.1em",
    height: "1.1em"
  },
  button3: {
    margin: theme.spacing.unit * 2,
    height: "6em",
    width: "6em"
  },
  icon3: {
    width: "1.8em",
    height: "1.8em"
  },
  icon4: {
    width: "2.5em",
    height: "2.5em"
  },
  video: {
    position: "fixed",
    top: "50%",
    left: "50%",
    transform: "translate(-50%, -50%)",
    width: "100%",
    height: "auto",
    zIndex: 0
  },
  eject: {
    position: "absolute",
    top: "5%",
    left: "5%"
  },
  time: {
    position: "absolute",
    top: "5%",
    right: "5%"
  }
});

class ConsumptionArtworkDemo extends Component {
  render() {
    const ih = window.innerHeight;
    const { classes } = this.props;
    const title = "Consumption Artwork with a very long title that should wrap because reasons, dude. now can i make this go 3 lines so i know how to chop it off...";
    const subtitle = "Demo of the thing that is very long and very wrappy and how long should this be to prove my damn point i don't know. and can this go 3 lines so i know to chop it off?";
    const leftValue = "35:00";
    const rightValue = "1:40:00";
    const progress = <LinearProgress variant="determinate" value={35} />;

    const buttonClass =
      ih > 900
        ? classes.primaryButton1080
        : ih > 595
        ? classes.primaryButton720
        : classes.primaryButton;
    const iconClass =
      ih > 900
        ? classes.primaryIcon1080
        : ih > 595
        ? classes.primaryIcon720
        : classes.primaryIcon;

    const buttonClass2 =
      ih > 900
        ? classes.secondaryButton1080
        : ih > 395
        ? classes.secondaryButton720
        : classes.secondaryButton;
    const iconClass2 =
      ih > 900
        ? classes.secondaryIcon1080
        : ih > 395
        ? classes.secondaryIcon720
        : classes.secondaryIcon;

    const buttons = [
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass} />
      </IconButton>,
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass} />
      </IconButton>,
      <IconButton
        variant="fab"
        color="secondary"
        className={buttonClass}
        aria-label="Delete"
      >
        <DeleteIcon className={iconClass} />
      </IconButton>,
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass} />
      </IconButton>,
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass} />
      </IconButton>
    ];

    const footerButtons = [
      <IconButton className={buttonClass2} aria-label="Delete">
        <DeleteIcon className={iconClass2} />
      </IconButton>,
      <IconButton className={buttonClass2} aria-label="Delete">
        <DeleteIcon className={iconClass2} />
      </IconButton>
    ];

    const video = (
      <img
        alt=""
        src="http://via.placeholder.com/1280x720"
        className={classes.video}
      />
    );

    const cprops = {
      title,
      subtitle,
      progress,
      buttons,
      footerButtons,
      leftValue,
      rightValue,
      video,
      artImgUrl: "./demo-album-cover.jpg"
    };

    return <ConsumptionArtwork {...cprops} />;
  }
}

export default withStyles(styles)(ConsumptionArtworkDemo);

==> muitv-0.6.1.tgz: package/src/components/demo/ConsumptionArtworkDemo.js <==
import React, { Component } from "react";

import ConsumptionArtwork from "components/layouts/ConsumptionArtwork";

import LinearProgress from "@material-ui/core/LinearProgress";
import { withStyles } from "@material-ui/core/styles";
import IconButton from "@material-ui/core/IconButton";
import DeleteIcon from "@material-ui/icons/Delete";

const styles = theme => ({
  primaryButton1080: {
    margin: theme.spacing(1),
    height: "3.0em",
    width: "3.0em"
  },
  primaryIcon1080: {
    width: "2.0em",
    height: "2.0em"
  },
  secondaryButton1080: {
    height: "2.2em",
    width: "2.2em"
  },
  secondaryIcon1080: {
    width: "1.8em",
    height: "1.8em"
  },

  primaryButton720: {
    margin: theme.spacing(1),
    width: "2.4em",
    height: "2.4em"
  },
  primaryIcon720: {
    width: "1.5em",
    height: "1.5em"
  },
  secondaryButton720: {
    width: "1.6em",
    height: "1.6em"
  },
  secondaryIcon720: {
    width: "1.1em",
    height: "1.1em"
  },

  primaryButton: {
    width: 56,
    height: 56
  },
  primaryIcon: {},
  secondaryButton: {},
  secondaryIcon: {},

  button1: {
    margin: theme.spacing(1),
    height: "2em",
    width: "2em"
  },
  icon1: {
    width: "1em",
    height: "1em"
  },
  button2: {
    margin: theme.spacing(1.3),
    height: "4.6em",
    width: "4.6em"
  },
  icon2: {
    width: "1.1em",
    height: "1.1em"
  },
  button3: {
    margin: theme.spacing(2),
    height: "6em",
    width: "6em"
  },
  icon3: {
    width: "1.8em",
    height: "1.8em"
  },
  icon4: {
    width: "2.5em",
    height: "2.5em"
  },
  video: {
    position: "fixed",
    top: "50%",
    left: "50%",
    transform: "translate(-50%, -50%)",
    width: "100%",
    height: "auto",
    zIndex: 0
  },
  eject: {
    position: "absolute",
    top: "5%",
    left: "5%"
  },
  time: {
    position: "absolute",
    top: "5%",
    right: "5%"
  }
});

class ConsumptionArtworkDemo extends Component {
  render() {
    const ih = window.innerHeight;
    const { classes } = this.props;
    const title = "Consumption Artwork with a very long title that should wrap because reasons, dude. now can i make this go 3 lines so i know how to chop it off...";
    const subtitle = "Demo of the thing that is very long and very wrappy and how long should this be to prove my damn point i don't know. and can this go 3 lines so i know to chop it off?";
    const leftValue = "35:00";
    const rightValue = "1:40:00";
    const progress = <LinearProgress variant="determinate" value={35} />;

    const buttonClass =
      ih > 900
        ? classes.primaryButton1080
        : ih > 595
        ? classes.primaryButton720
        : classes.primaryButton;
    const iconClass =
      ih > 900
        ? classes.primaryIcon1080
        : ih > 595
        ? classes.primaryIcon720
        : classes.primaryIcon;

    const buttonClass2 =
      ih > 900
        ? classes.secondaryButton1080
        : ih > 395
        ? classes.secondaryButton720
        : classes.secondaryButton;
    const iconClass2 =
      ih > 900
        ? classes.secondaryIcon1080
        : ih > 395
        ? classes.secondaryIcon720
        : classes.secondaryIcon;

    const buttons = [
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass} />
      </IconButton>,
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass} />
      </IconButton>,
      <IconButton
        variant="fab"
        color="secondary"
        className={buttonClass}
        aria-label="Delete"
      >
        <DeleteIcon className={iconClass} />
      </IconButton>,
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass} />
      </IconButton>,
      <IconButton className={buttonClass} aria-label="Delete">
        <DeleteIcon className={iconClass} />
      </IconButton>
    ];

    const footerButtons = [
      <IconButton className={buttonClass2} aria-label="Delete">
        <DeleteIcon className={iconClass2} />
      </IconButton>,
      <IconButton className={buttonClass2} aria-label="Delete">
        <DeleteIcon className={iconClass2} />
      </IconButton>
    ];

    const video = (
      <img
        alt=""
        src="http://via.placeholder.com/1280x720"
        className={classes.video}
      />
    );

    const cprops = {
      title,
      subtitle,
      progress,
      buttons,
      footerButtons,
      leftValue,
      rightValue,
      video,
      artImgUrl: "./demo-album-cover.jpg"
    };

    return <ConsumptionArtwork {...cprops} />;
  }
}

export default withStyles(styles)(ConsumptionArtworkDemo);
